<?php
/**
 * Magento Module implementing MojeID
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@czniccommerce.cz so we can send you a copy immediately.
 * 
 * @copyright  Copyright (c) 2008 CzNic Commerce (http://www.czniccommerce.cz)
 *
 */
/**
 * 
 * @category   Cznic
 * @package    Cznic_Mojeid
 * @author     CzNic Commerce Team <info@czniccommerce.cz>
 */

class Cznic_Mojeid_Helper_Data extends Mage_Core_Helper_Abstract
{
	public function getOpenIdStore()
	{
    	$store_path = $this->getOpenIdStorePath();
		$store_path = Mage::getBaseDir().'/'.$store_path;
    	
    	if (!file_exists($store_path) && !mkdir($store_path)) 
    	{
        	Mage::throwException(Mage::helper("mojeid")->__("Could not create the FileStore director '%s' ",$store_path).Mage::helper("mojeid")->__(" Please check the effective permissions."));
        	exit(0);   
    	}
    	
    	return new Zend_OpenId_Consumer_Storage_File($store_path);
	}
	
      
	public function getConsumer() 
	{
   		 /**
    	 * Create a consumer object using the store object created
    	 * earlier.
     	*/
    	$store = $this->getOpenIdStore();
        return new Cznic_Mojeid_Model_Openid_Consumer($store,false);

	}
      
        
        

	public function getScheme() 
	{
    	$scheme = 'http';
    	if (isset($_SERVER['HTTPS']) and $_SERVER['HTTPS'] == 'on') 
    	{
        	$scheme .= 's';
    	}
    	return $scheme;
	}

	public function getMojeidLoginPostUrl()
	{
		return Mage::getUrl('mojeid/index/try');	
	}
	public function getReturnToUrl() 
	{
		return Mage::getUrl('*/*/finish');	
	}

	public function getTrustRootUrl() 
	{
		return $baseUrl = Mage::app()->getStore()->getUrl(); 
	}
	
	public function getCustomerLoginUrl()
	{
		return 'customer/account/login';	
	}
	public function getSregAttributesArray()
	{
		return $this->getAttributesArray("sreg");
	}
	
	private function getAttributesArray($type,$suffix = "")
	{
		$attribsCol =  $this->getConfig('default/mojeid')->asArray();
		$attribs = array();
		foreach($attribsCol as $key => $attrbGroup)
		{
			if(((string)strpos($key,'attributes'.$suffix))== "0")
			{
				foreach($attrbGroup as $attrKey => $attrData)
				{
					if(((string)strpos($attrKey,$type.'_'))== "0")
					{
						if($attrData == 'Yes')
							$attrData = 1;
						if($attrData == 1)
							$attrData = true;
						else
							$attrData = false;
						$attribs[str_replace($type."_","",$attrKey)] = $attrData;
					}
				}
			}
		}
		return $attribs;
	}
	
	public function getAxAttributesArray()
	{		
		$axAttribs = $this->getAttributesArray("ax","_main");		
		/*$billingReq = $this->isBillingRequired();
		$shippingReq = $this->isShippingRequired();
		
		if($billingReq != 0)
		{
			$tmpAttribs = $this->setValueToAll( $this->getAttributesArray("ax","_bill"),$billingReq == 1?1:0);
			$axAttribs = array_merge($axAttribs,$tmpAttribs);
		}
		if($shippingReq != 0)
		{
			$tmpAttribs = $this->setValueToAll($this->getAttributesArray("ax","_shipp"),$shippingReq == 1?1:0);
			$axAttribs = array_merge($axAttribs,$tmpAttribs);
		}*/
		$tmpAttribs = $this->setValueToAll( $this->getAttributesArray("ax","_bill"),$this->isBillingRequired());
		$axAttribs = array_merge($axAttribs,$tmpAttribs);
		
    $tmpAttribs = $this->setValueToAll($this->getAttributesArray("ax","_shipp"),$this->isShippingRequired());
		$axAttribs = array_merge($axAttribs,$tmpAttribs);
		
		return $axAttribs;		
	}
	
	protected function setValueToAll($array,$value)
	{
		foreach($array as $key => $data)
		{
			$array[$key] = $value;
		}
		return $array;		
	}
	
	public function getSregExt()
	{
		$sregAttr = $this->getSregAttributesArray();		
		return new Zend_OpenId_Extension_Sreg($sregAttr, null, 1.1);
	}
	
	public function getAxExt()
	{
		return new Cznic_Mojeid_Model_Openid_Extension_Ax($this->getAxAttributesArray());
	}
		
	public function createUrlIdentifier($identityName)
	{
		return $this->getOpenIdIdentityPrefix().$identityName.$this->getOpenIdIdentitySuffix();
	}
	
	public function getEndpoint(){
      return ( string ) $this->getConfig ( 'default/mojeid/settings/endpoint' );
  }
  
  public function isButtonLoginEnabled(){
      return ( bool ) Mage::getStoreConfig( 'mojeid/general/button_login' );
  }

  public function getButtonColor(){
      return ( string ) Mage::getStoreConfig( 'mojeid/general/button_color' );
  }
	
	protected function getOpenIdIdentityPrefix() {
		return ( string ) $this->getConfig ( 'default/mojeid/settings/identity/prefix' );
	}
	
	protected function getOpenIdIdentitySuffix() {
		return ( string ) $this->getConfig ( 'default/mojeid/settings/identity/suffix' );
	}
	
	protected function getOpenIdStorePath() {
		return ( string ) $this->getConfig ( 'default/mojeid/settings/openid_store_path' );
	}
	
	protected function isBillingRequired() {
		return ( int )$this->getConfig ( 'default/mojeid/attributes_main/billing_required' );
	}
	
	protected function isShippingRequired() {
		return ( int )$this->getConfig ( 'default/mojeid/attributes_main/shipping_required' );
	}
	
	public function getRegistrationUrl(){
        return ( string ) $this->getConfig ( 'default/mojeid/settings/registration_url' ); 
  }
	
	public function getWhyMojeidUrl() {
    return $this->isMotivationProgrammeParticipation()
      ? ( Mage::getBaseUrl() . Mage::getStoreConfig( 'mojeid/motivation_programme/motivation_programme_route' ) )
      : $this->getConfig ( 'default/mojeid/settings/why_mojeid_url' );
	}
  
	public function getNewMojeidUrl() {
    $url = $this->getConfig ( 'default/mojeid/settings/new_mojeid_url' );
		if ($this->isMotivationProgrammeParticipation()){
      $url .= '?realm='.Mage::getBaseUrl();
    }
    return $url;
	}
	
	public function isMotivationProgrammeParticipation(){
    return ( bool ) Mage::getStoreConfig( 'mojeid/motivation_programme/motivation_programme_enabled' );
  }
	
	protected function getConfig($configPath) {
		return Mage::getConfig ()->getNode ($configPath);
	}
  
/*
  public function getSupportImagesDir(){
    $dir = Mage::getBaseDir(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/small/';
    $locale = Mage::app()->getLocale()->getLocaleCode();;

    if (file_exists($dir.$locale))
        return $dir.$locale;
        
    return $dir.'en_US';
  }
  
  public function getSupportImagesUrl(){
    $dir = Mage::getBaseDir(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/small/';
    $url = Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/small/'; 
    $locale = Mage::app()->getLocale()->getLocaleCode();
    
    if (file_exists($dir.$locale))
        return $url.$locale;
        
    return $url.'en_US';
//    return Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/small';
  }
  
  public function getSupportImageUrl(){
     $path = '/mojeid/support/'.Mage::getStoreConfig( 'mojeid/support_mojeid/support_image_size' ).'/';
     $locale = Mage::app()->getLocale()->getLocaleCode();
     $file = Mage::getStoreConfig( 'mojeid/support_mojeid/support_image' );
      
     if (file_exists(Mage::getBaseDir(Mage_Core_Model_Store::URL_TYPE_MEDIA).$path.$locale.'/'.$file))
        return Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).$path.$locale.'/'.$file;
      
     return Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).$path.'en_US'.'/'.$file; 
     
  }*/
  public function getSupportImagesDir(){
    $dir = Mage::getBaseDir(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/';
    $locale = Mage::app()->getLocale()->getLocaleCode();;

    if (file_exists($dir.$locale))
        return $dir.$locale;
        
    return $dir.'en_US';
  }
  
  public function getSupportImagesUrl(){
    $dir = Mage::getBaseDir(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/';
    $url = Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/'; 
    $locale = Mage::app()->getLocale()->getLocaleCode();
    
    if (file_exists($dir.$locale))
        return $url.$locale;
        
    return $url.'en_US';
//    return Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).'/mojeid/support/small';
  }
  
  public function getSupportImageUrl(){
     $path = '/mojeid/support/';
     $locale = Mage::app()->getLocale()->getLocaleCode();
     $file = Mage::getStoreConfig( 'mojeid/support_mojeid/support_image' );
      
     if (file_exists(Mage::getBaseDir(Mage_Core_Model_Store::URL_TYPE_MEDIA).$path.$locale.'/'.$file))
        return Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).$path.$locale.'/'.$file;
      
     return Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_MEDIA).$path.'en_US'.'/'.$file; 
     
  }
  
  public function generateXrds($motivationProgrammeEnabled = false, $motivationProgrammeRoute = null){
    
    $baseUrl = Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_WEB);

    $isSetup = false;
    if ($baseUrl == '/'){ //while installing module need to use default base url
        $row = Mage::getSingleton('core/resource')
          ->getConnection('core_read')
            ->query('SELECT `value` FROM `core_config_data` WHERE `scope`="default" AND `path`="web/unsecure/base_url"')
              ->fetch(PDO::FETCH_ASSOC);
        $baseUrl = $row['value'];      
        $isSetup = true;
    }
    
    $xml = '<?xml version="1.0" encoding="UTF-8"?'.'>
    <xrds:XRDS xmlns:xrds="xri://$xrds" xmlns:openid="http://openid.net/xmlns/1.0" xmlns="xri://$xrd*($v*2.0)">
      <XRD>
        <Service>
          <Type>http://specs.openid.net/auth/2.0/return_to</Type>
          <URI>'. $baseUrl .'mojeid/index/finish/</URI>
        </Service>';
    if ($motivationProgrammeEnabled){
       $url = $motivationProgrammeRoute ? $motivationProgrammeRoute : $baseUrl .'mojeid/index/finish/';
       $xml .= '
        <Service>
          <Type>http://specs.nic.cz/registration/assert_url</Type> 
          <URI>'. $url .'</URI>
        </Service>';
    }
    $xml .= '
      </XRD>
    </xrds:XRDS>';

    file_put_contents(Mage::getBaseDir().DS.'xrds.xml', $xml);
    
    if (!$isSetup){
        Mage::getSingleton('core/session')->addSuccess($this->__('File xrds.xml regenerated.'));
    }
  }  
  	
}

?>