<?php
/** 
 * Magento Module implementing MojeID 
 * 
 * NOTICE OF LICENSE 
 * 
 * This source file is subject to the Open Software License (OSL 3.0) 
 * that is bundled with this package in the file LICENSE.txt. 
 * It is also available through the world-wide-web at this URL: 
 * http://opensource.org/licenses/osl-3.0.php 
 * 
 * 
 */

/** 
 * 
 * @category Cznic 
 * @package Cznic_Mojeid
 * 
 */

class Cznic_Mojeid_Model_Auth_Finish extends Mage_Core_Model_Abstract 
{
	private $_consumerData;
	private $_identity;
	private $_error;
	
	public function _construct() 
	{
		parent::_construct ();
	}
	
	private function escape($thing) {
	    return htmlentities($thing);
	}
	
	public function getCustomerData()
	{
		return $this->_consumerData;
	}
	
	public function getIdentity()
	{
		return $this->_identity;
	}
        
	function run() 
	{		
		$common = Mage::helper("mojeid");
		$consumer = $common->getConsumer();
		$extensions = array($common->getSregExt(),$common->getAxExt());
		
		$paramsArray = $_GET;
		if(count($paramsArray) == 0)
			$paramsArray = $_POST;
		
		
		if ($paramsArray['openid_mode'] == "cancel") 
		{
			$this->_error = "CANCELLED"; 
			return false;
		}
			
			
		if ($consumer->verify($paramsArray, $this->_identity, $extensions)) 
                {
                                $this->_consumerData = array();
                                foreach($extensions as $extension)
                                {
                                $extensionData = $extension->getProperties();
                                foreach($extensionData as $key => $data)
                                {
                                        //if(is_array($data))
                                        //	$data = implode("",$data);
                                        $this->_consumerData[strtolower($key)] = $data;
                                }
                                }		
                                //Mage::log('consumerData');
                                //Mage::log($this->_consumerData);
                                $this->_consumerData = $this->removeLastArray($this->_consumerData);
                                
                                return true;
                }
                else
                {
                        $this->_error = $consumer->getError();
                        return false;
                }
	}
        
	private function removeLastArray($array)
	{
		if(!is_array($array))
			return $array;
		foreach($array as $key => $data)
		{
			if(is_array($data) && $key != "s" && $key != "i"/* && $key != "mojeid"*/)
			{
				$data = implode("",$data);
      			$array[($key)] = $data;
			}
			else
				$array[$key] = $this->removeLastArray($data);
		}
		return $array;
	}
	
	
	public function validateConsumerData()
	{
	 //Mage::log($_POST);
		$common = Mage::helper("mojeid");
		$allAttribs = array_merge($common->getSregAttributesArray(),$common->getAxAttributesArray());

		$error = "Missing required attributes";
		
		foreach($allAttribs as $key => $value)
		{
			$key = strtolower($key);
			if($value == false)
				continue;
			else
			{
				$additionalKey = "";
				if(($index = strpos($key,"_")) != false)
				{
					$keys = explode("_",$key);
					$additionalKey = $keys[0];
					$key = $keys[1];
					
          if(!isset($this->_consumerData[$additionalKey]) || !isset($this->_consumerData[$additionalKey][$key]) ||$this->_consumerData[$additionalKey][$key] == "")
					//if($key!=='status' && (!isset($this->_consumerData[$additionalKey]) || !isset($this->_consumerData[$additionalKey][$key]) || $this->_consumerData[$additionalKey][$key] == ""))
          {
						Mage::log('missing req 1 for '.$additionalKey.' and '.$key);
            $this->_error = $error;
						return false;
					}
				}
				else 
				{
				  //prevod tel. cisla
				  if ($key=='phone' && isset($this->_consumerData[$key]))
			       $this->_consumerData[$key] = str_replace('.','',$this->_consumerData[$key]);

					//if(!isset($this->_consumerData[$key]) || $this->_consumerData[$key] == "")
					if(/*$key!=='status' && */(!isset($this->_consumerData[$key]) || $this->_consumerData[$key] == "")) //pridana vyjimka status					
					{
					  Mage::log('missing req 2 for key '.$key);
						$this->_error = $error;
						return false;
					}
				}				
			}
		}
		return true;
	}
	
	public function getMessage()
	{
		$message = Mage::helper("mojeid")->__('You have successfully verified %s as your identity.',$this->getIdentity());
		
		switch($this->_error)
		{
			case "CANCELLED":
				$message = Mage::helper("mojeid")->__('Verification cancelled.');
				break;
			case "Extension::parseResponse failure":
			case "Missing required attributes":
				$message = Mage::helper("mojeid")->__("MojeID authentication failed.");
				$message .= " ".Mage::helper("mojeid")->__("Required attributes haven't been recived!");
				break;
			case "":
				break;
			default:
				$message = $this->_error;
				break;
		}
		return $message;
	}
	
}
