<?php
/** 
 * Magento Module implementing MojeID 
 * 
 * NOTICE OF LICENSE 
 * 
 * This source file is subject to the Open Software License (OSL 3.0) 
 * that is bundled with this package in the file LICENSE.txt. 
 * It is also available through the world-wide-web at this URL: 
 * http://opensource.org/licenses/osl-3.0.php 
 * 
 * 
 */

/** 
 * 
 * @category Cznic 
 * @package Cznic_Mojeid
 * 
 */

class Cznic_Mojeid_Model_Customer extends Mage_Core_Model_Abstract 
{
	protected $_new;
	protected $_data;
	protected $_errorMessage;
	protected $_ok;
	protected $_customer;
	
	public function _construct() 
	{
		parent::_construct ();
	}
	
	public function loadCustomer($customerData)
	{
		$this->_ok = true;
		$this->_data = $customerData;
		$this->_new = false;
		$this->_customer = Mage::getModel('customer/customer')->setWebsiteId(Mage::app()->getWebsite()->getId())->loadByEmail($customerData['email']);
		
		if(!isset($this->_customer) || $this->_customer->getId() == "")
		{	
			$this->_new = true;
			//create new customer
			$this->_data['password'] = $this->_data['confirmation'] = $this->createPassword();
			$this->_ok = $this->createCustomer();			
		}
		return $this;
	}
	
	public function isNew()
	{
		return $this->_new;
	}
	
	public function isOk()
	{
		return $this->_ok;
	}
	
	public function getMessage()
	{
		return $this->_errorMessage;
	}
	
	public function getMagentoCustomer()
	{
		return $this->_customer;
	}
	
	
	protected function createCustomer()
	{
		$this->_customer = Mage::getModel('customer/customer')->setId(null);
		foreach (Mage::getConfig()->getFieldset('customer_account') as $code=>$node) 
		{
        	if ($node->is('create') && isset($this->_data[$code])) 
        	{
            	if ($code == 'email') 
            	{
                	$this->_data[$code] = trim($this->_data[$code]);
                }
                $this->_customer->setData($code, $this->_data[$code]);
            }
      	}
      	/**
         * Initialize customer group id
        */
        $this->_customer->getGroupId();
        
		try 
		{
        	$validationCustomer = $this->_customer->validate();
        	$errors = array();
            if (is_array($validationCustomer)) 
            {
            	$errors = array_merge($validationCustomer, $errors);
            }
            $validationResult = count($errors) == 0;

            if (true === $validationResult) 
            {            
            	$this->_customer->save();	
 				return true;
    
            } 
            else 
            {
            	if (is_array($errors)) 
                {
                	$this->_errorMessage = "";
                	foreach ($errors as $errorMessage) 
                	{
                		$this->_errorMessage .= $errorMessage;
                    }
                }
                else 
                {
                    $this->_errorMessage =  Mage::helper("mojeid")->__('Invalid customer data').$errors;
                }
                return false;
            }
     	}
        catch (Exception $e) 
        {
        	$this->_errorMessage =  Mage::helper("mojeid")->__('Cannot save the customer.').$e->getMessage();
        	return false;
        }
	}
	
	protected function createPassword()
	{
		$pass = time()."Cznic".rand(0,1000000000)."Cznic";		
		foreach($this->_data as $key => $data)
		{
			if(is_array($data))
			{
				foreach($data as $subkey => $subdata)
					$pass .= $subdata.rand(5000,100000);
			}
			else
			{
				$tmp = "";
				if(($num = rand(0,1000))> 500)
					$tmp = $data.$num;
				else 
					$tmp = md5($data.$key.$num);
				$pass .= $tmp;	
			
			}
		}
		$pass = md5(sha1($pass));
		return $pass;
	}
	
	public function updateData()
	{
		$result = true;
                //Mage::log('_data');
                //Mage::log($this->_data);
		foreach($this->_data as $key => $data)
		{
			if($key == "i")
			{
				$result = $result && $this->updateAddress($this->mapMojeidToMagento($data),'billing');
			}
			else if($key == "s")
			{
				$result = $result && $this->updateAddress($this->mapMojeidToMagento($data),'shipping');
			}
                        else if($key == "mojeid")
			{
				//$this->_customer->setData($key.'_'.$data);
			}
			else
			{
				if($key != 'status' && $key != 'email' && $data != "")
				{	
					$this->_customer->setData($key,$data);
				}
			}
		}
		//add mojeid marker
        $this->_customer->setData('mojeid',1);
        //$this->_customer->setData('mojeid_status',$this->_data['mojeid']['status']);
        $this->_customer->setData('mojeid_status',$this->_data['status']);

//        Mage::log('customer');
//        Mage::log($this->_customer->getData());       
		$this->_customer->save();	
		return $result;	
	}
	
	protected function mapMojeidToMagento($addressData)
	{
		if(isset($addressData['country']))
			$addressData['country_id'] = $addressData['country'];
			
		return $addressData;
	}
	
	protected function updateAddress($addressData,$type)
	{		
		$address = $this->findAddress($type);
		if($address === false)
		{      		
			$address = Mage::getModel('customer/address')->setId(null);
			$address->setCustomerId($this->_customer->getId());
			$address->setCustomer($this->_customer); 
				
			if(isset($this->_data['firstname']))
				$addressData['firstname'] = $this->_data['firstname'];
			if(isset($this->_data['lastname']))
				$addressData['lastname'] = $this->_data['lastname'];
			if(isset($this->_data['phone']))
				$addressData['telephone'] = $this->_data['phone'];
		}
		
		$attribs = $address->getAttributes();
		
		$address->setData($addressData);
		
		$addressValidation = $address->validate();
        if (true === $addressValidation) 
        {
        	if($type == 'billing')
				$address->setIsDefaultBilling(1);
			else if($type == 'shipping')
				$address->setIsDefaultShipping(1);
        	$address->setCustomerId($this->_customer->getId()); 
        	$address->save();
        	return true;
        }
        else if (is_array($addressValidation)) 
        {
        	$this->_errorMessage = Mage::helper("mojeid")->__('Invalid customer address.');
            foreach ($addressValidation as $errorMessage) 
            {
             	$this->_errorMessage .= $errorMessage;
            }
       	}
        else 
        {
        	$this->_errorMessage =  Mage::helper("mojeid")->__('Invalid customer address.').$addressValidation;
        }
        return false;              	
	}
	
	protected function findAddress($type)
	{
		$addresses = $this->_customer->getAddresses();
		foreach($addresses as $address)
		{
            switch($type)  
            {
            	case 'billing':
            		if($address->getIsDefaultBilling())
            			return $address;
            		break;
            	case 'shipping':
            		if($address->getIsDefaultShipping())
            			return $address;
            		break; 
            	default:
            		break;        		
            }  			
		}
		return false;	
	}
}
